@@ -22,23 +22,23 @@
 ##' @export
 "print.trivPenalNL" <- function (x, digits = max(options()$digits - 4, 6), ...)
 {
-
+  
   #if (x$istop == 1){
-    # plot des coefficient dependant du temps
-   # if (any(x$nvartimedep != 0)) par(mfrow=c(sum(as.logical(x$nvartimedep)),max(x$nvartimedep)))
-   # if ((x$nvartimedep[1] != 0) & (x$istop == 1)){
-   #   for (i in 0:(x$nvartimedep[1]-1)){
-   #     matplot(x$BetaTpsMat[,1],x$BetaTpsMat[,(2:4)+4*i],col="blue",type="l",lty=c(1,2,2),xlab="t",ylab="beta(t)",main=paste("Recurrent : ",x$Names.vardep[i+1]),ylim=c(min(x$BetaTpsMat[,-1]),max(x$BetaTpsMat[,-1])))
-   #   }
-   # }
-   # if ((x$nvartimedep[2] != 0) & (x$istop == 1)){
-   #   for (i in 0:(x$nvartimedep[2]-1)){
-   #     matplot(x$BetaTpsMatT[,1],x$BetaTpsMatT[,(2:4)+4*i],col="blue",type="l",lty=c(1,2,2),xlab="t",ylab="beta(t)",main=paste("Death : ",x$Names.vardepT[i+1]),ylim=c(min(x$BetaTpsMatT[,-1]),max(x$BetaTpsMatT[,-1])))
-   #   }
-   # }
+  # plot des coefficient dependant du temps
+  # if (any(x$nvartimedep != 0)) par(mfrow=c(sum(as.logical(x$nvartimedep)),max(x$nvartimedep)))
+  # if ((x$nvartimedep[1] != 0) & (x$istop == 1)){
+  #   for (i in 0:(x$nvartimedep[1]-1)){
+  #     matplot(x$BetaTpsMat[,1],x$BetaTpsMat[,(2:4)+4*i],col="blue",type="l",lty=c(1,2,2),xlab="t",ylab="beta(t)",main=paste("Recurrent : ",x$Names.vardep[i+1]),ylim=c(min(x$BetaTpsMat[,-1]),max(x$BetaTpsMat[,-1])))
+  #   }
+  # }
+  # if ((x$nvartimedep[2] != 0) & (x$istop == 1)){
+  #   for (i in 0:(x$nvartimedep[2]-1)){
+  #     matplot(x$BetaTpsMatT[,1],x$BetaTpsMatT[,(2:4)+4*i],col="blue",type="l",lty=c(1,2,2),xlab="t",ylab="beta(t)",main=paste("Death : ",x$Names.vardepT[i+1]),ylim=c(min(x$BetaTpsMatT[,-1]),max(x$BetaTpsMatT[,-1])))
+  #   }
+  # }
   #}
-
-
+  
+  
   if (!is.null(cl <- x$call)){
     cat("Call:\n")
     dput(cl)
@@ -48,7 +48,7 @@
     if (x$AG == TRUE){
       cat("\n      Calendar timescale")
     }
-
+    
     cat("\n")
   }
   if (!is.null(x$fail)) {
@@ -59,7 +59,7 @@
   on.exit(options(savedig))
   coef <- x$coef
   nvar <- length(x$coef)
-
+  
   if (is.null(coef)){
     x$varH<-matrix(x$varH)
     x$varHIH<-matrix(x$varHIH)
@@ -77,43 +77,43 @@
     }
   }
   #AD
-
-
-
+  
+  
+  
   indic_alpha <- 1
-
+  
   if (x$istop == 1){
     if (!is.null(coef)){
-
-        seH <- sqrt(diag(x$varH))
-        seHIH <- sqrt(diag(x$varHIH))
-
-        if (x$typeof == 0){
-          
-          #tmp <- cbind(coef, exp(coef), seH, seHIH, coef/seH, signif(1 - pchisq((coef/seH)^2, 1), digits - 1))
-          #if(x$global_chisq.testR==1) tmpwald <- cbind(x$global_chisqR,x$dof_chisqR,x$p.global_chisqR)
-          #if(x$global_chisq.testT==1) tmpwalddc <- cbind(x$global_chisqT,x$dof_chisqT,x$p.global_chisqT)
-          tmp <- cbind(coef, exp(coef), seH, seHIH, coef/seH, ifelse(signif(1 - pchisq((coef/seH)^2, 1), digits - 1) == 0, "< 1e-16", signif(1 - pchisq((coef/seH)^2, 1), digits - 1)))
-          if(x$global_chisq.testR==1) tmpwald <- cbind(x$global_chisqR, x$dof_chisqR, ifelse(x$p.global_chisqR == 0, "< 1e-16", x$p.global_chisqR))
-          if(x$global_chisq.testT==1) tmpwalddc <- cbind(x$global_chisqT, x$dof_chisqT, ifelse(x$p.global_chisqT == 0, "< 1e-16", x$p.global_chisqT))
-          
-          if(x$global_chisq.testKG==1) tmpwaldKG <- cbind(x$global_chisqKG,x$dof_chisqKG,ifelse(x$p.global_chisqKG == 0, "< 1e-16", x$p.global_chisqKG))
-          if(x$global_chisq.testKD==1) tmpwaldKD <- cbind(x$global_chisqKD,x$dof_chisqKD,ifelse(x$p.global_chisqKD == 0, "< 1e-16", x$p.global_chisqKD))
-          
-        }else{
-          
-          #tmp <- cbind(coef, exp(coef), seH, coef/seH, signif(1 - pchisq((coef/seH)^2, 1), digits - 1))
-          #if(x$global_chisq.testR==1) tmpwald <- cbind(x$global_chisqR,x$dof_chisqR,x$p.global_chisqR)
-          #if(x$global_chisq.testT==1) tmpwalddc <- cbind(x$global_chisqT,x$dof_chisqT,x$p.global_chisqT)
-          tmp <- cbind(coef, exp(coef), seH, coef/seH, ifelse(signif(1 - pchisq((coef/seH)^2, 1), digits - 1) == 0, "< 1e-16", signif(1 - pchisq((coef/seH)^2, 1), digits - 1)))
-          if(x$global_chisq.testR==1) tmpwald <- cbind(x$global_chisqR, x$dof_chisqR, ifelse(x$p.global_chisqR == 0, "< 1e-16", x$p.global_chisqR))
-          if(x$global_chisq.testT==1) tmpwalddc <- cbind(x$global_chisqT, x$dof_chisqT, ifelse(x$p.global_chisqT == 0, "< 1e-16", x$p.global_chisqT))
-          
-          
-          if(x$global_chisq.testKG==1) tmpwaldKG <- cbind(x$global_chisqKG,x$dof_chisqKG,ifelse(x$p.global_chisqKG == 0, "< 1e-16", x$p.global_chisqKG))
-          if(x$global_chisq.testKD==1) tmpwaldKD <- cbind(x$global_chisqKD,x$dof_chisqKD,ifelse(x$p.global_chisqKD == 0, "< 1e-16", x$p.global_chisqKD))
-          
-        }
+      
+      seH <- sqrt(diag(x$varH))
+      seHIH <- sqrt(diag(x$varHIH))
+      
+      if (x$typeof == 0){
+        
+        #tmp <- cbind(coef, exp(coef), seH, seHIH, coef/seH, signif(1 - pchisq((coef/seH)^2, 1), digits - 1))
+        #if(x$global_chisq.testR==1) tmpwald <- cbind(x$global_chisqR,x$dof_chisqR,x$p.global_chisqR)
+        #if(x$global_chisq.testT==1) tmpwalddc <- cbind(x$global_chisqT,x$dof_chisqT,x$p.global_chisqT)
+        tmp <- cbind(coef, exp(coef), seH, seHIH, coef/seH, signif(1 - pchisq((coef/seH)^2, 1), digits - 1))
+        if(x$global_chisq.testR==1) tmpwald <- cbind(x$global_chisqR, x$dof_chisqR, ifelse(x$p.global_chisqR == 0, "< 1e-16", x$p.global_chisqR))
+        if(x$global_chisq.testT==1) tmpwalddc <- cbind(x$global_chisqT, x$dof_chisqT, ifelse(x$p.global_chisqT == 0, "< 1e-16", x$p.global_chisqT))
+        
+        if(x$global_chisq.testKG==1) tmpwaldKG <- cbind(x$global_chisqKG,x$dof_chisqKG,ifelse(x$p.global_chisqKG == 0, "< 1e-16", x$p.global_chisqKG))
+        if(x$global_chisq.testKD==1) tmpwaldKD <- cbind(x$global_chisqKD,x$dof_chisqKD,ifelse(x$p.global_chisqKD == 0, "< 1e-16", x$p.global_chisqKD))
+        
+      }else{
+        
+        #tmp <- cbind(coef, exp(coef), seH, coef/seH, signif(1 - pchisq((coef/seH)^2, 1), digits - 1))
+        #if(x$global_chisq.testR==1) tmpwald <- cbind(x$global_chisqR,x$dof_chisqR,x$p.global_chisqR)
+        #if(x$global_chisq.testT==1) tmpwalddc <- cbind(x$global_chisqT,x$dof_chisqT,x$p.global_chisqT)
+        tmp <- cbind(coef, exp(coef), seH, coef/seH, signif(1 - pchisq((coef/seH)^2, 1), digits - 1))
+        if(x$global_chisq.testR==1) tmpwald <- cbind(x$global_chisqR, x$dof_chisqR, ifelse(x$p.global_chisqR == 0, "< 1e-16", x$p.global_chisqR))
+        if(x$global_chisq.testT==1) tmpwalddc <- cbind(x$global_chisqT, x$dof_chisqT, ifelse(x$p.global_chisqT == 0, "< 1e-16", x$p.global_chisqT))
+        
+        
+        if(x$global_chisq.testKG==1) tmpwaldKG <- cbind(x$global_chisqKG,x$dof_chisqKG,ifelse(x$p.global_chisqKG == 0, "< 1e-16", x$p.global_chisqKG))
+        if(x$global_chisq.testKD==1) tmpwaldKD <- cbind(x$global_chisqKD,x$dof_chisqKD,ifelse(x$p.global_chisqKD == 0, "< 1e-16", x$p.global_chisqKD))
+        
+      }
       cat("\n")
       cat(" Mechanistic Trivariate Joint Model for Longitudinal Data, Recurrent Events and a Terminal Event","\n")
       if (x$typeof == 0){
@@ -125,38 +125,38 @@
       if(x$leftCensoring==TRUE)cat("   and assuming left-censored longitudinal outcome \n")
       if(x$link=='Random-effects') cat("   Association function: random effects","\n")
       if(x$link=='Current-level') cat("   Association function: current level of the longitudinal outcome","\n")
-
-
+      
+      
       cat("\n")
       #AL:
       if(x$typeof==0){ind <- 6}
       else {ind <- 5}
-
-
+      
+      
       if(sum(tmp[,ind]<1e-16)>=1){
         d1 <- dim(tmp)[1]
         d2 <- dim(tmp)[2]
         which <- which(tmp[,ind]<1e-16)
-
+        
         sprint<-paste("%.",digits-2,"e",sep="")
         tmp2 <- matrix(c(sprintf(sprint,tmp[,ind])),d1,1)
-
+        
         tmp2[which,1]<-"<1e-16"
-
+        
         sprint<-paste("%.",digits,"f",sep="")
         tmp <- matrix(c(sprintf(sprint,tmp[,-ind])),d1,d2-1)
         tmp <- cbind(tmp,tmp2)
-
+        
       }
-
+      
       if (x$typeof == 0){
         if(x$global_chisq.testR==1){
           dimnames(tmpwald) <- list(x$names.factorR,c("chisq", "df", "global p"))
-
+          
         }
         if(x$global_chisq.testKG==1){
           dimnames(tmpwaldKG) <- list(x$names.factorKG,c("chisq", "df", "global p"))
-
+          
         }
         if(x$global_chisq.testKD==1){
           dimnames(tmpwaldKD) <- list(x$names.factorKD,c("chisq", "df", "global p"))
@@ -164,18 +164,18 @@
         }
         if(x$global_chisq.testT==1){
           dimnames(tmpwalddc) <- list(x$names.factorT,c("chisq", "df", "global p"))
-
+          
         }
         dimnames(tmp) <- list(names(coef), c("coef", "exp(coef)",
                                              "SE coef (H)", "SE coef (HIH)", "z", "p"))
       }else{
         if(x$global_chisq.testR==1){
           dimnames(tmpwald) <- list(x$names.factorR,c("chisq", "df", "global p"))
-
+          
         }
         if(x$global_chisq.testKG==1){
           dimnames(tmpwaldKG) <- list(x$names.factorKG,c("chisq", "df", "global p"))
-
+          
         }
         if(x$global_chisq.testKD==1){
           dimnames(tmpwaldKD) <- list(x$names.factorKD,c("chisq", "df", "global p"))
@@ -183,12 +183,12 @@
         }
         if(x$global_chisq.testT==1){
           dimnames(tmpwalddc) <- list(x$names.factorT,c("chisq", "df", "global p"))
-
+          
         }
         dimnames(tmp) <- list(names(coef), c("coef", "exp(coef)",
                                              "SE coef (H)", "z", "p"))
       }
-
+      
       cat("\n")
       
       bio_pam <- cbind(c(x$y_0, x$K_G0, x$K_D0, x$lambda),c(x$se.y_0, x$se.K_G0, x$se.K_D0, x$se.lambda),
@@ -198,28 +198,28 @@
                          ifelse(signif(1 - pchisq((x$K_D0/x$se.K_D0)^2, 1), digits - 1) == 0, "< 1e-16", signif(1 - pchisq((x$K_D0/x$se.K_D0)^2, 1), digits - 1)),
                          ifelse(signif(1 - pchisq((x$lambda/x$se.lambda)^2, 1), digits - 1) == 0, "< 1e-16", signif(1 - pchisq((x$lambda/x$se.lambda)^2, 1), digits - 1))))
       
-       dimnames(bio_pam) <- list(c("Initial level: y_0", "Natural net growth: K_G0",
+      dimnames(bio_pam) <- list(c("Initial level: y_0", "Natural net growth: K_G0",
                                   "Drug induced decline: K_D0", "Resistance to the drug: lambda" )
                                 , c("estimation", "SE estimation (H)", "z", "p"))
       cat("Biomarker parameters:\n")
       cat("\n")
       prmatrix(bio_pam)
-
-        if (x$noVarKG == 0){
-          cat("Longitudinal outcome (tumor growth):\n")
-          cat("---------------- \n")
-          prmatrix(tmp[(x$nvarR+x$nvarEnd+1):(x$nvarR+x$nvarEnd + x$nvarKG),-2 ,drop=FALSE],quote=FALSE,right=TRUE)
-          if(x$global_chisq.testKG==1){
-            cat("\n")
-            prmatrix(tmpwaldKG)
-          }
-        }else{
+      
+      if (x$noVarKG == 0){
+        cat("Longitudinal outcome (tumor growth):\n")
+        cat("---------------- \n")
+        prmatrix(tmp[(x$nvarR+x$nvarEnd+1):(x$nvarR+x$nvarEnd + x$nvarKG),-2 ,drop=FALSE],quote=FALSE,right=TRUE)
+        if(x$global_chisq.testKG==1){
+          cat("\n")
+          prmatrix(tmpwaldKG)
+        }
+      }else{
         cat("\n")
         cat("Longitudinal outcome (tumor growth): No fixed covariates \n")
         cat("---------------- \n")
         cat("\n")
       }
-
+      
       if (x$noVarKD == 0){
         cat("Longitudinal outcome (tumor decline):\n")
         cat("---------------- \n")
@@ -235,105 +235,105 @@
         cat("\n")
       }
       cat("\n")
-
-    #  if (x$nvarnotdep[1] == 0){
-     #   cat("Recurrences:\n")
-    ##    cat("------------- \n")
-    #    cat("No constant coefficients, only time-varying effects of the covariates \n")
-    #  }else{
-        if (x$noVarRec== 0){
-          cat("Recurrences:\n")
-          cat("------------- \n")
-          prmatrix(tmp[1:x$nvarR, ,drop=FALSE],quote=FALSE,right=TRUE)
-          if(x$global_chisq.testR==1){
-            cat("\n")
-            prmatrix(tmpwald)
-          }
-        }else{
-          cat("\n")
-          
-          if (x$joint.clust == 1) cat("Recurrences: No covariates \n")
-          cat("------------- \n")
+      
+      #  if (x$nvarnotdep[1] == 0){
+      #   cat("Recurrences:\n")
+      ##    cat("------------- \n")
+      #    cat("No constant coefficients, only time-varying effects of the covariates \n")
+      #  }else{
+      if (x$noVarRec== 0){
+        cat("Recurrences:\n")
+        cat("------------- \n")
+        prmatrix(tmp[1:x$nvarR, ,drop=FALSE],quote=FALSE,right=TRUE)
+        if(x$global_chisq.testR==1){
           cat("\n")
+          prmatrix(tmpwald)
         }
-    #  }
+      }else{
+        cat("\n")
+        
+        if (x$joint.clust == 1) cat("Recurrences: No covariates \n")
+        cat("------------- \n")
+        cat("\n")
+      }
+      #  }
       cat("\n")
-   #   if (x$nvarnotdep[2] == 0){
-   #     cat("Terminal event:\n")
-   #     cat("---------------- \n")
-   #     cat("No constant coefficients, only time-varying effects of the covariates \n")
-    #  }else{
-        if (x$noVarEnd == 0){
-          cat("Terminal event:\n")
-          cat("---------------- \n")
-          prmatrix(tmp[(x$nvarR+1):(x$nvarR+x$nvarEnd), ,drop=FALSE],quote=FALSE,right=TRUE)
-          if(x$global_chisq.testT==1){
-            cat("\n")
-            prmatrix(tmpwalddc)
-          }
-        }else{
+      #   if (x$nvarnotdep[2] == 0){
+      #     cat("Terminal event:\n")
+      #     cat("---------------- \n")
+      #     cat("No constant coefficients, only time-varying effects of the covariates \n")
+      #  }else{
+      if (x$noVarEnd == 0){
+        cat("Terminal event:\n")
+        cat("---------------- \n")
+        prmatrix(tmp[(x$nvarR+1):(x$nvarR+x$nvarEnd), ,drop=FALSE],quote=FALSE,right=TRUE)
+        if(x$global_chisq.testT==1){
+          cat("\n")
+          prmatrix(tmpwalddc)
+        }
+      }else{
         cat("\n")
         cat("Terminal event: No covariates \n")
         cat("---------------- \n")
         cat("\n")
         cat("\n")
       }
-   #   }
+      #   }
       cat("\n")
     }
-  
-   
- 
-
-
+    
+    
+    
+    
+    
     #AD:
-
+    
     cat(" \n")
-
+    
     cat("Components of Random-effects covariance matrix B1: \n")
     tab.B1 <- round(x$B1,6)
     dimnames(tab.B1) <- list(x$names.re,rep("",dim(x$B1)[1]))
     prmatrix(tab.B1)
-
-
+    
+    
     cat("\n")
-
+    
     cat("Recurrent event and longitudinal outcome association: \n")
     if(x$link=='Random-effects'){
-      tab.Asso <- cbind(x$etaR, x$se.etaR, x$etaR/x$se.etaR, ifelse(signif(1 - pchisq((x$etaR/x$se.etaR)^2, 1), digits - 1) == 0, "< 1e-16", signif(1 - pchisq((x$etaR/x$se.etaR)^2, 1), digits - 1)))
+      tab.Asso <- cbind(x$etaR, x$se.etaR, x$etaR/x$se.etaR, signif(1 - pchisq((x$etaR/x$se.etaR)^2, 1), digits - 1))
       
       if(sum(tab.Asso[,4]<1e-16)>1){
         d1 <- dim(tab.Asso)[1]
         d2 <- dim(tab.Asso)[2]
         which <- which(tab.Asso[,4]<1e-16)
-
+        
         sprint<-paste("%.",digits-2,"e",sep="")
         tmp2 <- matrix(c(sprintf(sprint,tab.Asso[,4])),d1,1)
-
+        
         tmp2[which,1]<-"<1e-16"
         sprint<-paste("%.",digits,"f",sep="")
         tab.Asso <- matrix(c(sprintf(sprint,tab.Asso[,-4])),d1,d2-1)
         tab.Asso <- cbind(tab.Asso,tmp2)
-
+        
       }
       dimnames(tab.Asso) <- list(paste("Asso:",x$names.re,sep=""),c("coef",  "SE", "z", "p"))
       prmatrix(tab.Asso,quote=FALSE,right=TRUE)
     }else{
-      tab.Asso <- cbind(x$etaR, x$se.etaR, x$etaR/x$se.etaR, ifelse(signif(1 - pchisq((x$etaR/x$se.etaR)^2, 1), digits - 1) == 0, "< 1e-16", signif(1 - pchisq((x$etaR/x$se.etaR)^2, 1), digits - 1)))
+      tab.Asso <- cbind(x$etaR, x$se.etaR, x$etaR/x$se.etaR, signif(1 - pchisq((x$etaR/x$se.etaR)^2, 1), digits - 1))
       
       if(sum(tab.Asso[,4]<1e-16)>1){
         d1 <- dim(tab.Asso)[1]
         d2 <- dim(tab.Asso)[2]
         which <- which(tab.Asso[,4]<1e-16)
-
+        
         sprint<-paste("%.",digits-2,"e",sep="")
         tmp2 <- matrix(c(sprintf(sprint,tab.Asso[,4])),d1,1)
-
+        
         tmp2[which,1]<-"<1e-16"
         sprint<-paste("%.",digits,"f",sep="")
         tab.Asso <- matrix(c(sprintf(sprint,tab.Asso[,-4])),d1,d2-1)
         tab.Asso <- cbind(tab.Asso,tmp2)
-
+        
       }
       dimnames(tab.Asso) <- list("Current level",c("coef",  "SE", "z", "p"))
       prmatrix(tab.Asso,quote=FALSE,right=TRUE)
@@ -341,50 +341,50 @@
     cat("\n")
     cat("Terminal event and longitudinal outcome association: \n")
     if(x$link=='Random-effects'){
-
-      tab.Asso <- cbind(x$etaT, x$se.etaT, x$etaT/x$se.etaT, ifelse(signif(1 - pchisq((x$etaT/x$se.etaT)^2, 1), digits - 1) == 0, "< 1e-16", signif(1 - pchisq((x$etaT/x$se.etaT)^2, 1), digits - 1)))
+      
+      tab.Asso <- cbind(x$etaT, x$se.etaT, x$etaT/x$se.etaT, signif(1 - pchisq((x$etaT/x$se.etaT)^2, 1), digits - 1))
       
       if(sum(tab.Asso[,4]<1e-16)>1){
         d1 <- dim(tab.Asso)[1]
         d2 <- dim(tab.Asso)[2]
         which <- which(tab.Asso[,4]<1e-16)
-
+        
         sprint<-paste("%.",digits-2,"e",sep="")
         tmp2 <- matrix(c(sprintf(sprint,tab.Asso[,4])),d1,1)
-
+        
         tmp2[which,1]<-"<1e-16"
         sprint<-paste("%.",digits,"f",sep="")
         tab.Asso <- matrix(c(sprintf(sprint,tab.Asso[,-4])),d1,d2-1)
         tab.Asso <- cbind(tab.Asso,tmp2)
-
+        
       }
       dimnames(tab.Asso) <- list(paste("Asso:",x$names.re,sep=""),c("coef",  "SE", "z", "p"))
       prmatrix(tab.Asso,quote=FALSE,right=TRUE)
     }else{
-      tab.Asso <- cbind(x$etaT, x$se.etaT, x$etaT/x$se.etaT, ifelse(signif(1 - pchisq((x$etaT/x$se.etaT)^2, 1), digits - 1) == 0, "< 1e-16", signif(1 - pchisq((x$etaT/x$se.etaT)^2, 1), digits - 1)))
+      tab.Asso <- cbind(x$etaT, x$se.etaT, x$etaT/x$se.etaT, signif(1 - pchisq((x$etaT/x$se.etaT)^2, 1), digits - 1))
       
       if(sum(tab.Asso[,4]<1e-16)>1){
         d1 <- dim(tab.Asso)[1]
         d2 <- dim(tab.Asso)[2]
         which <- which(tab.Asso[,4]<1e-16)
-
+        
         sprint<-paste("%.",digits-2,"e",sep="")
         tmp2 <- matrix(c(sprintf(sprint,tab.Asso[,4])),d1,1)
-
+        
         tmp2[which,1]<-"<1e-16"
         sprint<-paste("%.",digits,"f",sep="")
         tab.Asso <- matrix(c(sprintf(sprint,tab.Asso[,-4])),d1,d2-1)
         tab.Asso <- cbind(tab.Asso,tmp2)
-
+        
       }
       dimnames(tab.Asso) <- list("Current level",c("coef",  "SE", "z", "p"))
       prmatrix(tab.Asso,quote=FALSE,right=TRUE)
     }
-
+    
     cat("\n")
-
+    
     cat("Residual standard error: ",round(x$ResidualSE,6), " (SE (H): ", round(x$se.ResidualSE,6), ") \n \n")
-
+    
     cat(" Frailty parameter for the association between recurrent events and terminal event: \n")
     temp <- diag(x$varH)[1]
     seH.frail <- sqrt(((2 * (x$sigma2^0.5))^2) * temp) # delta methode
@@ -392,13 +392,13 @@
     seHIH.frail <- sqrt(((2 * (x$sigma2^0.5))^2) * temp) # delta methode
     p<-signif(1 - pnorm(x$sigma2/seH.frail), digits - 1)
     if(p==0)p<-"<1e-16"
-      cat("   sigma square (variance of Frailties):", x$sigma2, "(SE (H):",seH.frail, ")", "p =",noquote(p), "\n")
+    cat("   sigma square (variance of Frailties):", x$sigma2, "(SE (H):",seH.frail, ")", "p =",noquote(p), "\n")
     p<-signif(1 - pchisq((x$alpha/sqrt(diag(x$varH))[2])^2,1), digits - 1)
     if(p==0)p<-"<1e-16"
     cat("   alpha (for terminal event):", x$alpha, "(SE (H):",sqrt(diag(x$varH))[2], ")", "p =", noquote(p), "\n")
-
+    
     cat(" \n")
-
+    
     if (x$typeof == 0){
       cat(paste("   penalized marginal log-likelihood =", round(x$logLikPenal,2)))
       cat("\n")
@@ -433,8 +433,8 @@
     }
     #AD:
     cat("\n")
-
-      cat("   n subjects=", x$groups)
+    
+    cat("   n subjects=", x$groups)
     cat("\n")
     cat("   n repeated measurements=", x$n.measurements)
     if(x$leftCensoring)cat("\n      Percentage of left-censored measurements=",round(x$prop.censored,4)*100,"%\n      Censoring threshold s=",x$leftCensoring.threshold)
@@ -455,9 +455,9 @@
     cat("\n")
     cat("\n")
     cat("   number of iterations: ", x$n.iter,"\n")
-
-
-
+    
+    
+    
     if (x$typeof == 0){
       cat("\n")
       cat("   Exact number of knots used: ", x$n.knots, "\n")
@@ -468,7 +468,7 @@
     cat("      Gaussian quadrature method: ",x$methodGH,"with",x$n.nodes, "nodes",sep=" ", "\n")
   }else{
     if (!is.null(coef)){
-
+      
       cat("\n")
       cat("  Longitudinal Data, Recurrent Event and Terminal Event Joint Model","\n")
       if (x$typeof == 0){
@@ -478,7 +478,7 @@
       }
       if (any(x$nvartimedep != 0)) cat("  and some time-dependant covariates","\n")
       if(x$leftCensoring==TRUE)cat("  and assuming left-censored longitudinal outcome \n")
-
+      
       if (x$noVarY == 1){
         cat("\n")
         cat("    Longitudinal Outcome: No fixed covariates \n")
@@ -495,12 +495,12 @@
         cat("    -------------- \n")
         cat("\n")
       }
-
+      
       cat("\n")
-
+      
       cat("   Convergence criteria: \n")
       cat("   parameters =",signif(x$EPS[1],3),"likelihood =",signif(x$EPS[2],3),"gradient =",signif(x$EPS[3],3),"\n")
-
+      
       cat("\n")
       cat("   n=", x$n)
       if (length(x$na.action)){
@@ -511,13 +511,13 @@
       cat("   n subjects=", x$groups)
       cat("\n")
       cat("   n repeated measurements=", x$n.measurements)
-
-        cat("\n")
-
+      
+      cat("\n")
+      
       cat("   n recurrent events=", x$n.events)
       cat("\n")
       cat("   n terminal events=", x$n.deaths)
-
+      
       cat("\n")
     }
   }
