@@ -239,12 +239,13 @@
 
     implicit none
 
+    integer::m,i,k,id,nsujet,nobs
     double precision::funcpi,thn,th,z,temp1,temp2,valT
     double precision,dimension(m,1)::Uscore,Uscore2
     double precision,dimension(m)::b
     double precision,dimension(m,m)::V
     double precision,dimension(nsujet)::rlindiv
-    integer::m,i,k,id,nsujet,nobs
+    
     integer,dimension(nsujet)::indT
 
     V = 0.d0
@@ -303,9 +304,9 @@
 !------------------------------------------------------------
 
     double precision function funcpi(nobs,b,np,id,thi,jd,thj,i,choix,valT)
-
-    use comon,only:typeof,nst,nbintervR,nbintervDC,nva,ve,effet,nz1,nz2, &
-    zi,ttt,c,stra,date,datedc,ndate,ndatedc,nva1,nva2,vedc,t0,t1,t1dc,tttdc,g,cdc
+    
+    !use comon,only:typeof,stra,c,cdc,nva1,nva2,nva,nst,nbintervR,nbintervDC,ve,effet,nz1,nz2, &
+    !zi,ttt,date,datedc,ndate,ndatedc,vedc,t0,t1,t1dc,tttdc,g
 
     implicit none
 
@@ -380,9 +381,9 @@
 
     double precision function func1E(frail,bh,np,i,nobs,valT,all) ! integrale 1 au numerateur
     ! recurrences + deces
-
+    !use comon,only:stra
     use comon,only:typeof,nst,nbintervR,nbintervDC,nva,ve,effet,nz1,nz2, &
-    zi,ttt,c,stra,date,datedc,ndate,ndatedc,nva1,nva2,vedc,t0,t1,t1dc,tttdc,g,cdc
+    zi,ttt,c,date,datedc,ndate,ndatedc,nva1,nva2,vedc,t0,t1,t1dc,tttdc,g,cdc
 
     IMPLICIT NONE
 
@@ -396,7 +397,7 @@
     double precision::vet,vet2,alpha,theta
     double precision,dimension(2)::su,sut1,sut0,sudc
     double precision::lam,lamdc,temp
-    double precision::gammaJ
+    double precision::logGammaJ
 
     n = 0
     betaR = 0.d0
@@ -571,7 +572,7 @@
     endif
 
     ! densite de la loi gamma pour les effets aleatoires
-    func1E = func1E * (frail**(1.d0/theta-1.d0)*dexp(-frail/theta))/(dexp(gammaJ(1.d0/theta))*theta**(1.d0/theta))
+    func1E = func1E * (frail**(1.d0/theta-1.d0)*dexp(-frail/theta))/(dexp(logGammaJ(1.d0/theta))*theta**(1.d0/theta))
 
 1000 continue
 
@@ -584,8 +585,9 @@
     double precision function func2E(frail,bh,np,i,nobs,valT) ! integrale 2 au denominateur
     ! recurrences
 
+    !use comon,only:stra,datedc,ndatedc,t1dc,cdc
     use comon,only:typeof,nst,nbintervR,nbintervDC,nva,ve,effet,nz1,nz2, &
-    zi,ttt,c,stra,date,datedc,ndate,ndatedc,nva1,nva2,vedc,t0,t1,t1dc,tttdc,g,cdc
+    zi,ttt,c,date,ndate,nva1,nva2,vedc,t0,t1,tttdc,g
 
     IMPLICIT NONE
 
@@ -599,7 +601,7 @@
     double precision::vet,vet2,alpha,theta
     double precision,dimension(2)::su,sut1,sut0,sudc
     double precision::lam,lamdc,temp
-    double precision::gammaJ
+    double precision::logGammaJ
 
     n = 0
     betaR = 0.d0
@@ -736,7 +738,7 @@
     end if
 
     ! densite de la loi gamma pour les effets aleatoires
-    func2E = func2E * (frail**(1.d0/theta-1.d0)*dexp(-frail/theta))/(dexp(gammaJ(1.d0/theta))*theta**(1.d0/theta))
+    func2E = func2E * (frail**(1.d0/theta-1.d0)*dexp(-frail/theta))/(dexp(logGammaJ(1.d0/theta))*theta**(1.d0/theta))
 
 1000 continue
 
