@@ -3,7 +3,8 @@
 !========================          funcpajng NEW         ====================
     double precision function funcpaGcpm(b,np,id,thi,jd,thj,k0)
 
-    use comon,only:cens,nbintervR,nbintervDC,t0,t1,t0dc,t1dc,c,cdc,nsujet,nva,nva1,nva2, &
+    !use comon,only:cens
+    use comon,only:nbintervR,nbintervDC,t0,t1,t0dc,t1dc,c,cdc,nsujet,nva,nva1,nva2, &
     nst,effet,stra,ve,vedc,ng,g,nig,AG,indic_ALPHA,alpha,theta,auxig,aux1,aux2,res1,res3, &
     ttt,tttdc,betacoef,kkapa
     use tailles
@@ -16,7 +17,7 @@
     integer::jj,gg,gg2
     integer::nb,np,id,jd,i,j,k,cptg,l,ig,choix
     integer,dimension(ngmax)::cpt
-    double precision::thi,thj,dnb,sum,inv,res,int,gammaJ
+    double precision::thi,thj,dnb,sum,inv,res,int,logGammaJ
     double precision,dimension(ngmax)::res2,res1dc,res2dc,res3dc
     double precision,dimension(np)::b,bh
     double precision,dimension(2)::k0
@@ -204,7 +205,7 @@
 
         res = 0.d0
         cptg = 0
-!     gam2 = gammaJ(inv)
+!     gam2 = logGammaJ(inv)
 ! k indice les groupes
 
         do k=1,ng
@@ -212,7 +213,7 @@
             if(cpt(k).gt.0)then
                 nb = nig(k)
                 dnb = dble(nig(k))
-!     gam1 = gammaJ(dnb + inv) 
+!     gam1 = logGammaJ(dnb + inv) 
                 if (dnb.gt.1.d0) then
                     do l=1,nb
                         sum=sum+dlog(1.d0+theta*dble(nb-l))
@@ -417,7 +418,7 @@
             sum=0.d0
             if(cpt(k).gt.0)then
                 res= res + res2(k) + res2dc(k) &
-                - gammaJ(1.d0/theta)-dlog(theta)/theta &
+                - logGammaJ(1.d0/theta)-dlog(theta)/theta &
                 + dlog(integrale3(k))
 
                 if ((res.ne.res).or.(abs(res).ge. 1.d30)) then
