@@ -19,7 +19,7 @@
     integer::jj,gg,gg2
     double precision::som11,som21,som1,som2
     integer,dimension(ngmax)::cpt
-    double precision::thi,thj,dnb,sum,inv,res,int,gammaJ
+    double precision::thi,thj,dnb,sum,inv,res,int,logGammaJ
     double precision,dimension(ngmax)::res2,res1dc,res2dc,res3dc
     double precision,dimension(np)::b,bh
     double precision,dimension(2)::k0
@@ -457,7 +457,7 @@
                     dlog(integrale1(k)) - dlog(integrale2(k))
                 else
                     res = res + res2dc(k) - &
-                    gammaJ(1.d0/theta)-dlog(theta)/theta + &
+                    logGammaJ(1.d0/theta)-dlog(theta)/theta + &
                     dlog(integrale1(k))
                 endif
 
