@@ -5,12 +5,14 @@
     double precision function funcpajcpm_log(b,np,id,thi,jd,thj,k0)
 
     use tailles
+    ! use comon,only:nst,AG,t0dc,res4
     use comon,only:nbintervR,nbintervDC,ttt,tttdc,betacoef, &
-    t0,t1,t0dc,t1dc,c,cdc,nsujet,nva,nva1,nva2,nst, &
-    effet,stra,ve,vedc,ng,g,nig,AG,indic_ALPHA,ALPHA,sig2, &
-    auxig,aux1,aux2,res1,res3,res4,kkapa,nstRec
+    t0,t1,t1dc,c,cdc,nsujet,nva,nva1,nva2, &
+    effet,stra,ve,vedc,ng,g,nig,indic_ALPHA,ALPHA,sig2, &
+    auxig,aux1,aux2,res1,res3,kkapa,nstRec
     use residusM
-    use comongroup,only:vet,vet2,the1,the2
+    !use comongroup,only:the1,the2
+    use comongroup,only:vet,vet2
 
     IMPLICIT NONE
 
@@ -237,7 +239,7 @@
 !                   write(*,*)'************** TAYLOR *************'
             !    res= res + res2(k) &
             !    + res2dc(k)  &
-            !    - gammaJ(1./theta)-dlog(theta)/theta  &
+            !    - logGammaJ(1./theta)-dlog(theta)/theta  &
             !    + dlog(integrale3(k))
             !endif
             if ((res.ne.res).or.(abs(res).ge. 1.d30)) then
