@@ -181,7 +181,7 @@
             end do
             
             !stop
-            ! les y jusqu' predtimerec2
+            ! les y jusqu'? predtimerec2
             yy_matrice = 0.d0
             it = 1
             do kk=1,npred0    
@@ -193,10 +193,10 @@
     
                       
             ! Calcul des risques de base
-            ! A chaque fois, calcul pour :
-            ! DC au temps de base (predtimerec2(1,1)) et  l'horizon (predtimerec2(1,nrec0+2))
-            ! Recurrence au temps de base et pour chaque temps de rechute entr (predtimerec2(i,ii))
-            ! pour chaque prediction demande  
+            ! A chaque fois, calcul? pour :
+            ! DC au temps de base (predtimerec2(1,1)) et ? l'horizon (predtimerec2(1,nrec0+2))
+            ! Recurrence au temps de base et pour chaque temps de rechute entr? (predtimerec2(i,ii))
+            ! pour chaque prediction demand?e  
     
             select case (typeof)
                 case(0)
@@ -308,8 +308,8 @@
     
             !=============================================
             ! Variabilite des proba predites
-            ! Creation d'un vecteur balea, qui correspond au vecteur b o chaque parametre
-            ! est tir au sort selon sa loi
+            ! Creation d'un vecteur balea, qui correspond au vecteur b o? chaque parametre
+            ! est tir? au sort selon sa loi
             ! seProba1(:)=0.d0; seProba2(:)=0.d0; seProba3(:)=0.d0;seProba4(:)=0.d0;
             ! lowProba1(:)=0.d0; lowProba2(:)=0.d0; lowProba3(:)=0.d0;lowProba4(:)=0.d0;
             ! highProba1(:)=0.d0; highProba2(:)=0.d0; highProba3(:)=0.d0;highProba4(:)=0.d0;
@@ -446,7 +446,7 @@
         end subroutine predict_tri  
     
      !**************************************************************************
-            !********* Gauss-Hermit pour la dimension 4 - modle trviarie b_10,b_11, b_12,v
+            !********* Gauss-Hermit pour la dimension 4 - mod?le trviarie b_10,b_11, b_12,v
             !**************************************************************************    
       SUBROUTINE gauherPred_tri4(ss,choix)    
         use tailles
@@ -481,7 +481,7 @@
         END SUBROUTINE gauherPred_tri4
         
             !**************************************************************************
-            !********* Gauss-Hermit pour la dimension 3 - modle trviarie b_10,b_11, v
+            !********* Gauss-Hermit pour la dimension 3 - mod?le trviarie b_10,b_11, v
             !**************************************************************************    
       SUBROUTINE gauherPred_tri3(ss,choix)    
         use tailles
@@ -633,7 +633,7 @@
     !=========================
       double precision function func1pred1GHtri(frail,frail2)
         ! calcul de l integrant (numerateur de la fonction de prediction)
-        use comon,only:etaydc,sigmae,netar,etayr,nb1,&
+        use comon,only:etaydc,sigmae,etayr,nb1,& !netar
             s_cag,s_cag_id,alpha,ut,utt,link,npp
             !etaydc2,etayr2,netadc,nva3,vey
         use donnees_indiv,only:nmescur,mu,z2,ycurrent,b1,nmescurr!x2cur,z1cur
@@ -754,7 +754,7 @@
       double precision  function func2pred1GHtri(frail,frail2)
         ! calcul de l integrant (denominateur de la fonction de prediction)
         use optim
-        use comon,only:etaydc,sigmae,netar,etayr,s_cag,s_cag_id,nb1,&
+        use comon,only:etaydc,sigmae,etayr,s_cag,s_cag_id,nb1,& !netar
             alpha,ut,utt,link,npp!,nva3,vey,netadc,etaydc2,etayr2
         use donnees_indiv,only:nmescur,mu,z2,ycurrent,b1,nmescurr!x2cur,z1cur,
         use prediction
@@ -866,7 +866,7 @@
     !=========================
       double precision function func1pred2GHtri(frail,frail2,frail3)
         ! calcul de l integrant (numerateur de la fonction de prediction)
-        use comon,only:etaydc,sigmae,netar,etayr,nb1,&
+        use comon,only:etaydc,sigmae,etayr,nb1,& !netar
             s_cag,s_cag_id,alpha,ut,utt,link,npp!netadc,nva3,vey
         use donnees_indiv,only:nmescur,mu,z2,ycurrent,b1,nmescurr!x2cur,z1cur
         use prediction
@@ -988,7 +988,7 @@
       double precision  function func2pred2GHtri(frail,frail2,frail3)
         ! calcul de l integrant (denominateur de la fonction de prediction)
         use optim
-        use comon,only:etaydc,sigmae,netar,etayr,nb1,&
+        use comon,only:etaydc,sigmae,etayr,nb1,& !netar
             s_cag,s_cag_id,alpha,ut,utt,link,npp !,nva3,vey,netadc
         use donnees_indiv,only:nmescur,mu,z2,ycurrent,b1,nmescurr!x2cur,z1cur    
         use prediction
@@ -1107,7 +1107,7 @@
     !=========================
       double precision function func1pred3GHtri(frail,frail2,frail3,frail4)
         ! calcul de l integrant (numerateur de la fonction de prediction)
-        use comon,only:etaydc,sigmae,netar,etayr,nb1,nea,&
+        use comon,only:etaydc,sigmae,etayr,nb1,nea,& !netar
             s_cag,s_cag_id,alpha,ut,utt,link,npp!netadc,nva3,vey
         use donnees_indiv,only:nmescur,mu,z2,ycurrent,b1,nmescurr!x2cur,z1cur
         use prediction
@@ -1231,7 +1231,7 @@
       double precision  function func2pred3GHtri(frail,frail2,frail3,frail4)
         ! calcul de l integrant (denominateur de la fonction de prediction)
         use optim
-        use comon,only:etaydc,sigmae,netar,etayr,nb1,nea,&
+        use comon,only:etaydc,sigmae,etayr,nb1,nea,& !netar
             s_cag,s_cag_id,alpha,ut,utt,link,npp !,nva3,vey,netadc
         use donnees_indiv,only:nmescur,mu,z2,ycurrent,b1,nmescurr!x2cur,z1cur    
         use prediction
